==> cdk-ssm-parameter-store-0.1.74.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.74](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.73...v0.1.74) (2021-04-03)

### [0.1.73](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.72...v0.1.73) (2021-04-02)

### [0.1.72](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.71...v0.1.72) (2021-04-01)

### [0.1.71](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.70...v0.1.71) (2021-03-31)

### [0.1.70](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.69...v0.1.70) (2021-03-30)

### [0.1.69](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.68...v0.1.69) (2021-03-29)

### [0.1.68](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.67...v0.1.68) (2021-03-27)

### [0.1.67](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.66...v0.1.67) (2021-03-26)

### [0.1.66](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.65...v0.1.66) (2021-03-25)

### [0.1.65](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.64...v0.1.65) (2021-03-24)

### [0.1.64](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.63...v0.1.64) (2021-03-22)

### [0.1.63](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.62...v0.1.63) (2021-03-21)

### [0.1.62](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.61...v0.1.62) (2021-03-20)

### [0.1.61](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.60...v0.1.61) (2021-03-19)

### [0.1.60](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.59...v0.1.60) (2021-03-18)

### [0.1.59](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.58...v0.1.59) (2021-03-09)

### [0.1.58](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.57...v0.1.58) (2021-03-08)

### [0.1.57](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.56...v0.1.57) (2021-03-07)

### [0.1.56](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.55...v0.1.56) (2021-03-06)

### [0.1.55](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.54...v0.1.55) (2021-03-05)

### [0.1.54](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.53...v0.1.54) (2021-03-04)

### [0.1.53](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.52...v0.1.53) (2021-03-03)

### [0.1.52](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.51...v0.1.52) (2021-03-02)

### [0.1.51](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.50...v0.1.51) (2021-03-01)

### [0.1.50](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.49...v0.1.50) (2021-02-28)

### [0.1.49](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.48...v0.1.49) (2021-02-27)

### [0.1.48](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.47...v0.1.48) (2021-02-26)

### [0.1.47](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.46...v0.1.47) (2021-02-25)

### [0.1.46](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.45...v0.1.46) (2021-02-24)

### [0.1.45](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.44...v0.1.45) (2021-02-23)

### [0.1.44](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.43...v0.1.44) (2021-02-21)

### [0.1.43](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.42...v0.1.43) (2021-02-20)

### [0.1.42](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.41...v0.1.42) (2021-02-19)

### [0.1.41](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.40...v0.1.41) (2021-02-18)

### [0.1.40](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.39...v0.1.40) (2021-02-18)

### [0.1.39](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.38...v0.1.39) (2021-02-17)

### [0.1.38](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.37...v0.1.38) (2021-02-16)

### [0.1.37](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.36...v0.1.37) (2021-02-15)

### [0.1.36](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.35...v0.1.36) (2021-02-14)

### [0.1.35](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.34...v0.1.35) (2021-02-13)

### [0.1.34](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.33...v0.1.34) (2021-02-12)

### [0.1.33](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.32...v0.1.33) (2021-02-11)

### [0.1.32](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.31...v0.1.32) (2021-02-10)

### [0.1.31](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.30...v0.1.31) (2021-02-09)

### [0.1.30](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.29...v0.1.30) (2021-02-08)

### [0.1.29](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.28...v0.1.29) (2021-02-07)

### [0.1.28](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.27...v0.1.28) (2021-02-06)

### [0.1.27](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.26...v0.1.27) (2021-02-05)


### Bug Fixes

* defaultReleaseBranch ([72b6b68](https://github.com/pahud/cdk-ssm-parameter-store/commit/72b6b68b3f5e82a5b895d55e4d1717d73d1d128c))
* minor ([b5c6454](https://github.com/pahud/cdk-ssm-parameter-store/commit/b5c6454fa7a50883ac83f9566a5e2602f8af1c17))

### [0.1.26](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.25...v0.1.26) (2021-02-03)

### [0.1.25](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.24...v0.1.25) (2021-02-02)

### [0.1.24](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.23...v0.1.24) (2021-02-01)

### [0.1.23](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.22...v0.1.23) (2021-01-30)

### [0.1.22](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.21...v0.1.22) (2021-01-29)

### [0.1.21](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.20...v0.1.21) (2021-01-28)

### [0.1.20](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.19...v0.1.20) (2021-01-18)

### [0.1.19](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.18...v0.1.19) (2021-01-16)

### [0.1.18](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.17...v0.1.18) (2021-01-15)

### [0.1.17](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.16...v0.1.17) (2021-01-13)

### [0.1.16](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.15...v0.1.16) (2021-01-12)

### [0.1.15](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.14...v0.1.15) (2021-01-11)

### [0.1.14](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.13...v0.1.14) (2021-01-10)

### [0.1.13](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.12...v0.1.13) (2021-01-09)

### [0.1.12](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.11...v0.1.12) (2021-01-08)

### [0.1.11](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.10...v0.1.11) (2021-01-07)

### [0.1.10](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.9...v0.1.10) (2021-01-06)

### [0.1.9](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.8...v0.1.9) (2021-01-05)

### [0.1.8](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.7...v0.1.8) (2021-01-04)

### [0.1.7](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.6...v0.1.7) (2021-01-04)


### Bug Fixes

* wront repository url ([5dc0167](https://github.com/pahud/cdk-ssm-parameter-store/commit/5dc0167c66a5dea8646f0c61dba4357d2239d085))

### 0.1.6 (2020-12-19)

### 0.1.5 (2020-10-24)

### 0.1.4 (2020-10-24)

### 0.1.3 (2020-10-24)

### 0.1.2 (2020-10-24)

### [0.1.1](https://github.com/pahud/gitpod-workspace/compare/v0.1.0...v0.1.1) (2020-10-24)

## 0.1.0 (2020-10-24)


### Features

* **dockerfile:** add jq support ([2937fc7](https://github.com/pahud/gitpod-workspace/commit/2937fc7b73d60d0722b60cd764d9f1f788efb5a5))
* **utils:** add refresh_credentials.sh ([4370f95](https://github.com/pahud/gitpod-workspace/commit/4370f953067f948e2e5567d04f82406277140feb))


### Bug Fixes

* **util:** update refresh_credentials.sh ([6525bbe](https://github.com/pahud/gitpod-workspace/commit/6525bbe97aa53ca0c01847ea60a5fe77f7cadf43))

==> cdk-ssm-parameter-store-0.1.81.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.81](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.80...v0.1.81) (2021-04-11)

### [0.1.80](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.79...v0.1.80) (2021-04-10)

### [0.1.79](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.78...v0.1.79) (2021-04-09)

### [0.1.78](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.77...v0.1.78) (2021-04-08)

### [0.1.77](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.76...v0.1.77) (2021-04-07)

### [0.1.76](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.75...v0.1.76) (2021-04-05)

### [0.1.75](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.74...v0.1.75) (2021-04-04)

### [0.1.74](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.73...v0.1.74) (2021-04-03)

### [0.1.73](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.72...v0.1.73) (2021-04-02)

### [0.1.72](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.71...v0.1.72) (2021-04-01)

### [0.1.71](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.70...v0.1.71) (2021-03-31)

### [0.1.70](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.69...v0.1.70) (2021-03-30)

### [0.1.69](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.68...v0.1.69) (2021-03-29)

### [0.1.68](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.67...v0.1.68) (2021-03-27)

### [0.1.67](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.66...v0.1.67) (2021-03-26)

### [0.1.66](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.65...v0.1.66) (2021-03-25)

### [0.1.65](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.64...v0.1.65) (2021-03-24)

### [0.1.64](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.63...v0.1.64) (2021-03-22)

### [0.1.63](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.62...v0.1.63) (2021-03-21)

### [0.1.62](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.61...v0.1.62) (2021-03-20)

### [0.1.61](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.60...v0.1.61) (2021-03-19)

### [0.1.60](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.59...v0.1.60) (2021-03-18)

### [0.1.59](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.58...v0.1.59) (2021-03-09)

### [0.1.58](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.57...v0.1.58) (2021-03-08)

### [0.1.57](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.56...v0.1.57) (2021-03-07)

### [0.1.56](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.55...v0.1.56) (2021-03-06)

### [0.1.55](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.54...v0.1.55) (2021-03-05)

### [0.1.54](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.53...v0.1.54) (2021-03-04)

### [0.1.53](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.52...v0.1.53) (2021-03-03)

### [0.1.52](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.51...v0.1.52) (2021-03-02)

### [0.1.51](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.50...v0.1.51) (2021-03-01)

### [0.1.50](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.49...v0.1.50) (2021-02-28)

### [0.1.49](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.48...v0.1.49) (2021-02-27)

### [0.1.48](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.47...v0.1.48) (2021-02-26)

### [0.1.47](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.46...v0.1.47) (2021-02-25)

### [0.1.46](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.45...v0.1.46) (2021-02-24)

### [0.1.45](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.44...v0.1.45) (2021-02-23)

### [0.1.44](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.43...v0.1.44) (2021-02-21)

### [0.1.43](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.42...v0.1.43) (2021-02-20)

### [0.1.42](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.41...v0.1.42) (2021-02-19)

### [0.1.41](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.40...v0.1.41) (2021-02-18)

### [0.1.40](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.39...v0.1.40) (2021-02-18)

### [0.1.39](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.38...v0.1.39) (2021-02-17)

### [0.1.38](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.37...v0.1.38) (2021-02-16)

### [0.1.37](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.36...v0.1.37) (2021-02-15)

### [0.1.36](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.35...v0.1.36) (2021-02-14)

### [0.1.35](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.34...v0.1.35) (2021-02-13)

### [0.1.34](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.33...v0.1.34) (2021-02-12)

### [0.1.33](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.32...v0.1.33) (2021-02-11)

### [0.1.32](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.31...v0.1.32) (2021-02-10)

### [0.1.31](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.30...v0.1.31) (2021-02-09)

### [0.1.30](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.29...v0.1.30) (2021-02-08)

### [0.1.29](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.28...v0.1.29) (2021-02-07)

### [0.1.28](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.27...v0.1.28) (2021-02-06)

### [0.1.27](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.26...v0.1.27) (2021-02-05)


### Bug Fixes

* defaultReleaseBranch ([72b6b68](https://github.com/pahud/cdk-ssm-parameter-store/commit/72b6b68b3f5e82a5b895d55e4d1717d73d1d128c))
* minor ([b5c6454](https://github.com/pahud/cdk-ssm-parameter-store/commit/b5c6454fa7a50883ac83f9566a5e2602f8af1c17))

### [0.1.26](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.25...v0.1.26) (2021-02-03)

### [0.1.25](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.24...v0.1.25) (2021-02-02)

### [0.1.24](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.23...v0.1.24) (2021-02-01)

### [0.1.23](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.22...v0.1.23) (2021-01-30)

### [0.1.22](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.21...v0.1.22) (2021-01-29)

### [0.1.21](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.20...v0.1.21) (2021-01-28)

### [0.1.20](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.19...v0.1.20) (2021-01-18)

### [0.1.19](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.18...v0.1.19) (2021-01-16)

### [0.1.18](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.17...v0.1.18) (2021-01-15)

### [0.1.17](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.16...v0.1.17) (2021-01-13)

### [0.1.16](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.15...v0.1.16) (2021-01-12)

### [0.1.15](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.14...v0.1.15) (2021-01-11)

### [0.1.14](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.13...v0.1.14) (2021-01-10)

### [0.1.13](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.12...v0.1.13) (2021-01-09)

### [0.1.12](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.11...v0.1.12) (2021-01-08)

### [0.1.11](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.10...v0.1.11) (2021-01-07)

### [0.1.10](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.9...v0.1.10) (2021-01-06)

### [0.1.9](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.8...v0.1.9) (2021-01-05)

### [0.1.8](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.7...v0.1.8) (2021-01-04)

### [0.1.7](https://github.com/pahud/cdk-ssm-parameter-store/compare/v0.1.6...v0.1.7) (2021-01-04)


### Bug Fixes

* wront repository url ([5dc0167](https://github.com/pahud/cdk-ssm-parameter-store/commit/5dc0167c66a5dea8646f0c61dba4357d2239d085))

### 0.1.6 (2020-12-19)

### 0.1.5 (2020-10-24)

### 0.1.4 (2020-10-24)

### 0.1.3 (2020-10-24)

### 0.1.2 (2020-10-24)

### [0.1.1](https://github.com/pahud/gitpod-workspace/compare/v0.1.0...v0.1.1) (2020-10-24)

## 0.1.0 (2020-10-24)


### Features

* **dockerfile:** add jq support ([2937fc7](https://github.com/pahud/gitpod-workspace/commit/2937fc7b73d60d0722b60cd764d9f1f788efb5a5))
* **utils:** add refresh_credentials.sh ([4370f95](https://github.com/pahud/gitpod-workspace/commit/4370f953067f948e2e5567d04f82406277140feb))


### Bug Fixes

* **util:** update refresh_credentials.sh ([6525bbe](https://github.com/pahud/gitpod-workspace/commit/6525bbe97aa53ca0c01847ea60a5fe77f7cadf43))
